#
# spec file for package neovim
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           neovim
Version:        0.2.0
Release:        6.1
Summary:        Vim-fork focused on extensibility and agility
License:        Apache-2.0
Group:          Productivity/Text/Editors
URL:            https://neovim.io/
Source:         https://github.com/neovim/neovim/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        nvim.desktop
Source2:        nvim.png
# PATCH-FIX-UPSTREAM CVE-2019-12735.patch boo#1137443 mcepl@suse.com
# Patch fixing the security issue "Modelines allow arbitrary code execution"
Patch0:         CVE-2019-12735.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gperf
BuildRequires:  hicolor-icon-theme
BuildRequires:  libmsgpack-devel >= 1.2.0
BuildRequires:  libmsgpackc-devel >= 1.2.0
BuildRequires:  lua51-BitOp
BuildRequires:  lua51-LPeg
BuildRequires:  lua51-mpack
BuildRequires:  luajit-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(jemalloc)
BuildRequires:  pkgconfig(libuv)
BuildRequires:  pkgconfig(termkey)
BuildRequires:  pkgconfig(unibilium)
BuildRequires:  pkgconfig(vterm)
Recommends:     %{name}-lang
Recommends:     python-neovim
Recommends:     python3-neovim
Recommends:     xsel

%description
Neovim is a refactor - and sometimes redactor - in the tradition of
Vim, which itself derives from Stevie. It is not a rewrite, but a
continuation and extension of Vim. Many rewrites, clones, emulators
and imitators exist; some are very clever, but none are Vim. Neovim
strives to be a superset of Vim, notwithstanding some intentionally
removed misfeatures; excepting those few and carefully-considered
excisions, Neovim is Vim. It is built for users who want the good
parts of Vim, without compromise, and more.

%lang_package

%prep
%setup -q
%autopatch -p1

cp -f %{SOURCE1} nvim.desktop
cp -f %{SOURCE2} nvim.png

# Remove __DATE__ and __TIME__.
BUILD_TIME=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%{H}:%{M}')
BUILD_DATE=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%{b} %{d} %{Y}')
sed -i "s/__TIME__/\"$BUILD_TIME\"/" $(grep -rl '__TIME__')
sed -i "s/__DATE__/\"$BUILD_DATE\"/" $(grep -rl '__DATE__')

%build
%cmake \
  -DLUA_PRG=%{_bindir}/lua \
  -DUSE_BUNDLED=OFF        \
  -DLUAJIT_USE_BUNDLED=OFF \
  -DENABLE_JEMALLOC=ON
make %{?_smp_mflags}

%install
%cmake_install

# Install desktop file.
install -Dpm 0644 nvim.desktop %{buildroot}/%{_datadir}/applications/nvim.desktop

# Install the icon.
install -Dpm 0644 nvim.png %{buildroot}/%{_datadir}/pixmaps/nvim.png

%suse_update_desktop_file -r nvim ConsoleOnly Application Utility TextEditor

%fdupes %{buildroot}%{_datadir}/
%find_lang nvim

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%license LICENSE
%doc BACKERS.md CONTRIBUTING.md README.md
%{_bindir}/nvim
%{_datadir}/nvim/
%{_datadir}/applications/nvim.desktop
%{_datadir}/pixmaps/nvim.png
%{_mandir}/man1/nvim.1%{?ext_man}

%files lang -f nvim.lang

%changelog
* Thu Jun  6 2019 Matej Cepl <mcepl@suse.com>
- boo#1137443: Add CVE-2019-12735.patch fixing the security bug
  "Modelines allow arbitrary code execution".
* Thu Jan 11 2018 ronisbr@gmail.com
- Run spec-cleaner.
- Replace `neovim.desktop` with `nvim.desktop` and `neovim.svg`
  with `nvim.png`.
  - Those two files were created by upstream in v0.2.1 and it was
    backported to v0.2.0 in Leap 42.3.
  - It also fixes boo#1075614 .
* Fri May  5 2017 ronisbr@gmail.com
- Run spec-cleaner.
- Update to version 0.2.0:
  * Features
  - bc4a2e1 help, man.vim: "outline" (TOC) feature #5169
  - 58422f1 'guicursor' works in the TUI (and sends info to UIs)
    [#6423]
  - 129f107 api: nvim_get_mode() #6247
  - 0b59f98 api/ui: externalize tabline #6583
  - bc6d868 'listchars': Whitespace highlight group #6367
  - 6afa7d6 writefile() obeys 'fsync' option #6427
  - c60e409 eval.c refactor (also improves some error messages)
    [#5119]
  - 9d200cd getcompletion("cmdline") #6376
  - 2ea7bfc terminal: Support extra arguments in 'shell'. #4504
  - bf51102 DirChanged autocmd #5928 #6262
  - 1743df8 'cpoptions': "_" flag to toggle cw behaviour #6235
  - 22337b1 CTRL-R omits trailing ^M when pasting to cmdline
    [#6137]
  - 0e44916 :edit allows unescaped spaces in filename #6119
  - abdbfd2 eval: Add id() function and make printf("%%p") useful
    [#6095]
  - bdfa147 findfile(), :find, gf work in :terminal. #6009
  - 2f38ed1 providers: Disable if g:loaded_* exists.
  - b5560a6 setpos() can set lowercase marks in other buffers
    [#5753]
  - 7c513d6 Throttle :! output, pulse "..." message. #5396
  - d2e8c76 v:exiting #5651
  - :terminal improvements #6185 #6142
  * cursor keeps position after leaving insert-mode.  4ceec30
  * Follows output only if cursor is at end of buffer.  e7bbd35
  * new option: 'scrollback' fedb844 quasi-support for undo and
  * 'modifiable' b45ddf7 disables 'list' by default disables
  * 'relativenumber' by default
  - :help now contains full API documentation at :help api.
  - man.vim saw numerous improvements.
  - Windows support:
  * Windows is no longer "experimental", it is fully supported.
  * Windows package includes a GUI, curl.exe and other
    utilities.
  * :terminal is not supported on Windows, yet. (Planned for
    0.2.1)
  * Security fixes
  - CVE-2017-5953
  - CVE-2017-6349
  - CVE-2017-6350
  - #6485
  * Changes
  - NVIM_TUI_ENABLE_CURSOR_SHAPE was removed. Use 'guicursor'
    instead. See
    https://github.com/neovim/neovim/wiki/Following-HEAD#20170402
  - 81525dc 'mouse=a' is no longer the default. (This may change
    again after it is improved.) #6022
  - 0c1f783 defaults: 'showcmd', 'belloff', 'ruler' #6087
  - eb0e94f api: {get,set}_option update local options as
    appropriate #6405
  - bdcb2a3 "Reading from stdin..." message was removed. #6298
  * Fixes
  - 12fc1de ops: fix i<c-r> with multi-byte text #6524
  - dd391bf Windows: system() and friends #6497
  - 13352c0 Windows: os_get_hostname() #6413
  - 16babc6 tui: Less-noisy mouse seqs #6411
  - 3a9dd13 (vim bug) folding edge-cases #6207
  - f6946c6 job-control: set CLOEXEC on pty processes. #5986
  - d1afd43 rplugin: Call s:LoadRemotePlugins() on startup.
  - 1215084 backtick-expansion works with shell=fish #6224
  - e32ec03 tui: Improved behavior after resize. #6202
  - 86c2adc edit.c: CTRL-SPC: Insert previously-inserted text.
    [#6090]
  - c318d8e b:changedtick now follows VimL rules #6112
  - 34e24cb terminal: Initialize colors in reverse order #6160
  - e889917 undo: Don't set b_u_curhead in ex_undojoin() #5869
  - d25649f undo: :earlier, g-: Set b_u_seq_cur correctly.
    (#6016)
  - 043d8ba 'Visual-mode put from @. register' #5782
  - 42c922b open_buffer(): Do BufEnter for directories.
  - 50d0d89 inccommand: Preview :sub commands only after
    delimiter #5932
  - 1420e10 CheckHealth improvements #5519
  - c8d5e92 jobstart(): Return -1 if cmd is not executable. #5671
* Mon Nov 28 2016 ronisbr@gmail.com
- Update to version 0.1.7:
  * Features
  - 0213e99 PR #5561 'inccommand'
  * Fixes
  - c685879 PR #5632 SECURITY FIX
  - d28d108 CheckHealth: Fix version comparison.
  - 7be113d PR #5670 shell_write_cb: Schedule error message.
  - 1d45637 jobs: ensure calling jobclose() on a pty job sends
    SIGHUP.
  - 36c0ec6 tui/suspend_event(): set STDIN to "blocking"
  - 7a4d069, cf52b88 man.vim: avoid errors in unusual
    circumstances
  - ed19873 PR #5546 ex_global: Catch CTRL-C even if it is
    mapped.
  * Changes
  - 9147331 PR #2905 encoding: only allow encoding=utf-8
  - 5f02608 PR #5636 build: Upgrade jemalloc
  - f1fed42 PR #5567 l10n: Update Ukrainian translation
* Mon Oct 31 2016 ronisbr@gmail.com
- Update to version 0.1.6:
  * Features:
  - 0b5a7e4 #4432 API: external UIs can render custom popupmenu
  - c6ac4f8 #4934 API: call any API method from vimscript
  - 31df051 #4568 API: nvim_call_atomic(): multiple calls in a
    single request
  - b268ba3 #5424 API: nvim_win_get_number(),
    nvim_tabpage_get_number()
  - e7e2844 has("nvim-1.2.3") checks for a specific Nvim version
  - 522b885 #5295, #5493 `:CheckHealth` checks tmux, terminfo,
    performance
  - 719dae2 #5384 events: allow event processing in getchar()
  - f25797f #5386 API: metadata: Nvim version & API level
  - 22dfe69 #5389 API: metadata: "since", "deprecated_since"
  - 605e743 Added QuickFixLine highlight group
  * Changes:
  - 4af6ec7 #5253 perf: Disable clipboard in do_cmdline()
  - 6e9f329 #5299 perf: Skip foldUpdate() in insert-mode.
  - 9d4fcec #5426 perf: Do not auto-update folds for some
    foldmethods.
  - eeec0ca #5419 tui: Default to normal-mode cursor shape.
  * Fixes:
  - e838452 #5436 tui: Fix "weird characters" / "bleeding
    termcodes"
  - 10a54ad #5243 signal_init: Always unblock SIGCHLD.
  - bccb49b #5316 eval.c: Fix memory leak for detached pty job
  - 626065d #5227 tchdir: New tab should inherit CWD.
  - cd321b7 #5292 getcwd(): Return empty string if CWD is
    invalid.
  - 6127eae shada: Fix non-writeable ShaDa directory handling
  - ca65514 #2789 system(): Respect shellxescape, shellxquote
  - 2daf54e #4874 Restore vim-like tab dragging
  - 0c536b5 #5319 syntax.c: Support bg/fg special color-names.
  - 3c53371 #4972 from justinmk/schedule-ui_refresh
  - 68bcb32 #4789 tui.c: Do not wait for tui loop on teardown.
  - c8b6ec2 #5409 v:count broken in command-line window
  - 6bc3bce #5461 fix emoji display
  - 51937e1 #5470 fix :terminal with :argadd, :argu
  - 79d77da #5481 external UIs: opening multiple files from
    command-line
  - 657ba62 #5501 rplugin: resolve paths in manifest file
  - 6a6f188 #5502 system('foo &', 'bar'): Show error, don't
    crash.
  - 1ff162c #5515 os_nodetype: open fd with O_NONBLOCK
  - 2a6c5bb #5450 modeline: Handle version number overflow.
  - 0ade1bb #5225 CI tests now run against Windows!
- Add gperf as a build dependency.
* Tue Aug 30 2016 sor.alexei@meowr.ru
- Update to version 0.1.5:
  * Breaking changes:
    + 'termguicolors' option enables "true color".
    NVIM_TUI_ENABLE_TRUE_COLOR is now ignored.
    + Remove ":oldfiles!", replaced by Vim's ":browse oldfiles".
  * Features:
    + Full :ruby support!
    + timers: timer_start(), timer_stop().
    + :CheckHealth command.
    + file: Add buffered reading and writing.
    Much faster shada file reading (important for startup time).
    + jobstart() learned 'rpc':
  - jobs and RPC channel IDs share the same "namespace".
  - jobstart() can start RPC channels, which allows scripts to
    handle 'stderr' on a RPC channel, like a typical non-RPC
    job.
  - jobpid()/jobstop() works on RPC jobs.
  - Deprecates rpcstart().
    + man.vim rewrite:
  - :Man command is enabled by default.
  - New features: completion, window handling, better parsing,
    and more.
    + capture() function (renamed to execute())
  - Supports nesting, including nested :redir.
    + rplugin manifest: default to XDG dir.
    + Better handling of mouse-clicks on concealed chars.
    + terminal: Ensure b:term_title always has a value.
    + tui: Assume 256 colours in most cases.
    + Always resize the :terminal.
    + api_info().
    + allow setting cwd in jobstart(), termopen().
    + support "special" highlight (undercurl).
    + mouse: Implement horizontal scroll.
  * Fixes:
    + Prevent data loss for process output streams.
    + 'process.c: Fix block in teardown'.
    + Prevent endless loop in printdigraph() (gh#neovim/neovim#5215).
    + timers: Avoid crash after processing events.
    + Set the default value for 'packpath'.
    + Restore double click.
    + readfile(): Less-disruptive readonly check.
    Fixes an issue where nvim unnecessarily "touched" open files.
    + Handle very long $XDG_DATA_DIRS.
    + option: Do not expand options in XDG vars.
    + server_init: Handle server_address_new() failure.
    + Fix v:register for clipboard=unnamed,unnamedplus.
    + 'Trigger TabNewEntered with T'.
    + synIDattr(): Return RRGGBB value for fg#.
- Correct group: Productivity/Text/Editors.
- Separate locales into neovim-lang.
- Some spec cleanup.
* Thu Apr 28 2016 ronisbr@gmail.com
- Update to version 0.1.4.
- Run spec-cleaner in `neovim.spec`.
- Replace lua51-MessagePack build dependency to lua51-mpack.
- Changelog:
    Features:
  * 5ebffaa :tcd for tab-local working directory (like :lcd,
    but for tabs)
  * d835c03 remote/define.vim: support remote function "range"
  * 007d573 json_encode/json_decode (with sophisticated error
    detection) #4131
  * b50afb4 clipboard: support "lemonade" tool
    Fixes:
  * cc1beec eval.c: Fix heap corruption error. #4592
  * 4043725 mbyte.c: Fix invalid memory access in
    utfc_ptr2char_len #4574
  * 4eb5827 Enable syntax/filetype by default. #4558
    Changes:
  * 5c6592f v:windowid is writeable (useful for GUIs) #4608A
* Thu Apr 14 2016 ronisbr@gmail.com
- Change icon 'neovim.svg' installation directory from
    %%{_datadir}/pixmaps/%%{name}.svg
  to
    %%{_datadir}/icons/hicolor/scalable/apps/%%{name}.svg
  as per dimstar request.
- Fix neovim.changes indentation.
* Sun Apr 10 2016 ronisbr@gmail.com
- Remove unneeded patches that were applied by upstream:
  * neovim_fix_locale_dir_01.patch
  * neovim_fix_locale_dir_02.patch
- Update to version 0.1.3.
- Changelog:
    Features:
  * f2ae5a9 Add TextYankPost and TextDeletePost autocmds
  * 44b2cef bufhl: new mechanism for plugins to add highlights
    to a buffer
  * 39c3842 Make set{qf,loc}list() take {title}
  * 77a7ca4 'shortmess': Add "F" flag. #4446
  * 99d4c8c keymap: Support <D-...> (super/command key).
    Fixes:
  * 14c9b30 terminal.c: temporary fix for incorrect paste
    handling
    Notable changes:
  * 50e129f defaults: Enable syntax and filetype plugins.
  * 4e39eee upgrade libvterm (improves terminal reflow)
* Tue Mar  8 2016 ronisbr@gmail.com
- Backport two patches that fix translations in Neovim:
  * neovim_fix_locale_dir_01.patch
  * neovim_fix_locale_dir_02.patch
- Update to version 0.1.2.
- Changelog:
    Features:
  * ef66249 tabline: Add %%[] atom to the tabline, for random
    commands on click
  * f338ea7 job control: implement jobpid() to get PID of job
  * d0d5d17 job control: add 'detach' option to jobstart
  * 7ad3f07 Add support for binary numbers
    Fixes:
  * 291495a regexp_nfa.c: Speed up find_match_text()
  * 317d5ca input: Do not set high-bit; preserve ALT modifier.
  * 3b7c409 shell: Unquote &shell* options before using them
    Notable changes:
  * 49b06a8 encoding: Always use "utf-8" as default for
    &encoding
  * 79a6983 ui: revert "gui_running" hack
    Other changes:
  * b4b4536 version: semver.org compliance
  * c6aa716 reproducible builds: Stop using __{DATE,TIME}__
  * 46bd3c0 clipboard: Check $DISPLAY. Prefer xsel. #4150
  * f6ecd12 job control: don't kill PTY processes on exit
  * 49f0417 clipboard: Detach clipboard helper, so contents is
    kept after nvim exit
  * 38435e8 python: Add missing I/O methods to RedirectStream
  * d26b01d eval: Use better error messages when failing to
    dump values
  * 62d137c Remove swapsync.
* Fri Jan 22 2016 ronisbr@gmail.com
- Add neovim desktop file.
* Mon Jan 11 2016 ronisbr@gmail.com
- Add neovim logo to the package.
* Sat Dec  5 2015 ronisbr@gmail.com
- Update to version 0.1.1.
- Changelog:
  * shada/msgpack editor plugin #3270
  * VimL Dict notifications #3603
  * Note: API for this feature may change.
  * :profile dump, :profile stop #2427
  * :oldfiles! #3611
  * TermOpen, TermClose events #3653
  * fix: shada/viminfo: Do not save unlisted and quickfix buffers
    [#3581]
* Thu Dec  3 2015 ronisbr@gmail.com
- Remove xclip of recommended packages list.
* Thu Dec  3 2015 ronisbr@gmail.com
- Add python-neovim and python3-neovim as recommended packages.
* Wed Dec  2 2015 ronisbr@gmail.com
- Initial version based on home:darix:neovim/neovim
